@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   */
 
@@ -48,7 +48,7 @@ int main(int argc, char **argv)
   aboutData.addCredit("Carsten Pfeiffer");
   aboutData.addCredit("Dave Corrie");
   aboutData.addCredit("Kai Jung", I18N_NOOP("6 new levels"), "jung@fh-fresenius.de");
-  aboutData.addAuthor("Danny Allen", 0, "danny@dannyallen.co.uk");
+  aboutData.addCredit("Danny Allen", I18N_NOOP("Game graphics and application icon"), "danny@dannyallen.co.uk");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
 
