@@ -8,6 +8,7 @@
 #define TOPLEVEL_H
 
 class GameWidget;
+class KAction;
 class KConfig;
 
 #include <kmainwindow.h>
@@ -49,10 +50,13 @@ class AtomTopLevel : public KMainWindow
 
   GameWidget *main;
 
-public slots:
+  KAction *redoAction, *undoAction;
 
-  // Shows a window for configuring the keybindings
-  void configkeys();
+  protected slots:
+  void enableRedo(bool enable);
+  void enableUndo(bool enable);
+
+public slots:
 
   // Shows a dialog for options other than keys
   void configopts();
