@@ -20,20 +20,16 @@
 
 KChatWidget::KChatWidget(QWidget *parent, const char *name) : chatDlg(parent, name)
 {
-	setMinimumSize(600, 180);
 	connect(sendBtn, SIGNAL(clicked()), this, SLOT(slotComputeMessage()));
 	connect(commentEdit, SIGNAL(returnPressed()), this, SLOT(slotComputeMessage()));
 	chatView->setFocusProxy(commentEdit);
+	chatView->setMinimumSize(0, 50);
 	commentEdit->installEventFilter(this);
 
 	m_currentNickname = QString::null;
 	slotAcceptMsg(false);
 }
 
-KChatWidget::~KChatWidget()
-{
-}
-
 void KChatWidget::clear()
 {
 	m_currentNickname = QString::null;
@@ -51,7 +47,7 @@ void KChatWidget::slotReceivedMessage(const QString &nickname, const QString &ms
 {
 	// Niko Z:
 	// IRC roxxx :)
-	if(msg.startsWith("/me ")) 
+	if(msg.startsWith("/me "))
 		chatView->append(QString(" * ") + nickname + QString(" ") + msg.mid(4));
 	else if(msg.startsWith("/nick "))
 		if(fromenemy)
