@@ -28,7 +28,6 @@
 #include <khelpmenu.h>
 #include <kaction.h>
 #include <kstdaction.h>
-#include <kkeydialog.h>
 #include <kstatusbar.h>
 #include <kstdgameaction.h>
 
@@ -63,26 +62,31 @@ KBBGame::KBBGame()
   pix[0] = new QPixmap();
   *pix[0] = BarIcon( pFNames[0] );
   if (!pix[0]->isNull()) {
-    kdDebug() << "Pixmap \"" << pFNames[0] << "\" loaded." << endl;
+    kdDebug(12009) << "Pixmap \"" << pFNames[0] << "\" loaded." << endl;
     for (i = 1; i < NROFTYPES; i++) {
       pix[i] = new QPixmap;
       *pix[i] = BarIcon( pFNames[i] );
       if (!pix[i]->isNull()) {
-	kdDebug() << "Pixmap \"" << pFNames[i] << "\" loaded." << endl;
+	kdDebug(12009) << "Pixmap \"" << pFNames[i] << "\" loaded." << endl;
       } else {
 	pix[i] = pix[i-1];
 	pix[i]->detach();
-	kdDebug() << "Cannot find pixmap \"" << pFNames[i] << "\". Using previous one." << endl;
+	kdDebug(12009) << "Cannot find pixmap \"" << pFNames[i] << "\". Using previous one." << endl;
       }
     }
   } else {
-    kdDebug() << "Cannot find pixmap \"" << pFNames[0] << "\". Pixmaps will not be loaded." << endl;
+    kdDebug(12009) << "Cannot find pixmap \"" << pFNames[0] << "\". Pixmaps will not be loaded." << endl;
     delete pix[0];
     delete pix;
     pix = NULL;
   }
   gr = new KBBGraphic( pix, this, "KBBGraphic" );
 
+  statusBar()->insertItem(i18n("Score: 0000"), SSCORE);
+  statusBar()->insertItem(i18n("Placed: 00 / 00"), SBALLS);
+  statusBar()->insertItem(i18n("Run: yesno"), SRUN);
+  statusBar()->insertItem(i18n("Size: 00 x 00"), SSIZE);
+
   initKAction();
 
   connect( gr, SIGNAL(inputAt(int,int,int)),
@@ -97,11 +101,6 @@ KBBGame::KBBGame()
 		 "Click here when you think you placed all the balls.") );
 		 */
 
-  statusBar()->insertItem(i18n("Score: 0000"), SSCORE);
-  statusBar()->insertItem(i18n("Placed: 00 / 00"), SBALLS);
-  statusBar()->insertItem(i18n("Run: yesno"), SRUN);
-  statusBar()->insertItem(i18n("Size: 00 x 00"), SSIZE);
-
   /*
      Game initializations
   */
@@ -145,28 +144,17 @@ KBBGame::KBBGame()
   } else tutorial = FALSE;
   tutorialAction->setChecked(tutorial);
 
-  QString s, s1;
-  int pos;
-  setMinSize();
-  gameResize();
-  if (kConf->hasKey( "appsize" )) {
-    s = kConf->readEntry( "appsize" );
-    kdDebug() << s << endl;
-    pos = s.find( 'x' );
-    s1 = s.right( s.length() - pos - 1 );
-    s.truncate( pos - 1 );
-    //    kdDebug() << s << endl;
-    //    kdDebug() << s1 << endl;
-    resize( s.toInt(), s1.toInt() );
-  }
-
+  setCentralWidget( gr );
+  
   setScore( 0 );
   ballsPlaced = 0;
-  updateStats();
-
-  setCentralWidget( gr );
+  
+	updateStats();
 
   newGame();
+	setMinSize();
+
+  setupGUI();
 }
 
 /*
@@ -184,8 +172,6 @@ KBBGame::~KBBGame()
   kConf->writeEntry( "Width", gr->numC() - 4);
   kConf->writeEntry( "Height", gr->numR() - 4);
   kConf->writeEntry( "tutorial", (int) tutorial );
-  s = QString("%1 x %2").arg(this->width()).arg(this->height() );
-  kConf->writeEntry( "appsize", s );
 
   delete gameBoard;
   // All the rest has "this" for parent so it doesn't need to be deleted.
@@ -248,10 +234,10 @@ void KBBGame::slotBalls()
           break;
       case 1:
           ok = setBalls( 6 );
-	  break;
+    break;
         case 2:
           ok = setBalls( 8 );
-	  break;
+    break;
   }
   if (!ok) {
     switch (balls) {
@@ -279,9 +265,9 @@ void KBBGame::newGame()
 
   if (running) {
     bool cancel;
-    cancel = KMessageBox::warningYesNo(0,
-	       i18n("Do you really want to give up this game?"))
-      == KMessageBox::No;
+    cancel = KMessageBox::warningContinueCancel(0,
+         i18n("Do you really want to give up this game?"),QString::null,i18n("Give Up"))
+      == KMessageBox::Cancel;
     if (cancel)
       return;
 
@@ -400,10 +386,10 @@ void KBBGame::giveUp()
 {
   if (running) {
     bool stop;
-    stop = KMessageBox::warningYesNo(0,
+    stop = KMessageBox::warningContinueCancel(0,
 			    i18n(
-			    "Do you really want to give up this game?"))
-      == KMessageBox::Yes;
+			    "Do you really want to give up this game?"),QString::null,i18n("Give Up"))
+      == KMessageBox::Continue;
 
     if (stop) {
       getResults();
@@ -454,10 +440,10 @@ bool KBBGame::setSize( int w, int h )
   bool ok = FALSE;
   if (((w+4) != gr->numC()) || ((h+4) != gr->numR())) {
     if (running) {
-      ok = KMessageBox::warningYesNo(0,
+      ok = KMessageBox::warningContinueCancel(0,
 			      i18n(
-			      "This will be the end of the current game!"))
-	== KMessageBox::Yes;
+			      "This will be the end of the current game!"),QString::null,i18n("End Game"))
+	== KMessageBox::Continue;
 
     } else ok = TRUE;
     if (ok) {
@@ -483,9 +469,9 @@ bool KBBGame::setBalls( int n )
   bool ok = FALSE;
   if (balls != n) {
     if (running) {
-      ok = KMessageBox::warningYesNo(0,
-			 i18n("This will be the end of the current game!"))
-	== KMessageBox::Yes;
+      ok = KMessageBox::warningContinueCancel(0,
+			 i18n("This will be the end of the current game!"),QString::null,i18n("End Game"))
+	== KMessageBox::Continue;
     } else ok = TRUE;
     if (ok) {
       balls = n;
@@ -690,7 +676,7 @@ void KBBGame::gotInputAt( int col, int row, int state )
 	setScore( score+1 );
 	break;
       case WRONGSTART:
-	kdDebug() << "Wrong start?! It should't happen!!" << endl;
+	kdDebug(12009) << "Wrong start?! It should't happen!!" << endl;
 	break;
       }
       break;
@@ -734,7 +720,8 @@ void KBBGame::initKAction()
   list.append(i18n(" 8 "));
   ballsAction->setItems(list);
   tutorialAction = new KToggleAction( i18n("&Tutorial"), 0, this, SLOT(tutorialSwitch()), actionCollection(), "options_tutorial" );
-  KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
+//  KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+//actionCollection());
 
 // keyboard only
   (void)new KAction( i18n("Move Down"), Qt::Key_Down, gr, SLOT(slotDown()), actionCollection(), "move_down" );
@@ -742,8 +729,6 @@ void KBBGame::initKAction()
   (void)new KAction( i18n("Move Left"), Qt::Key_Left, gr, SLOT(slotLeft()), actionCollection(), "move_left" );
   (void)new KAction( i18n("Move Right"), Qt::Key_Right, gr, SLOT(slotRight()), actionCollection(), "move_right" );
   (void)new KAction( i18n("Trigger Action"), Qt::Key_Return, gr, SLOT(slotInput()), actionCollection(), "move_trigger" );
-
-  createGUI();
 }
 
 void KBBGame::slotResize()
@@ -752,8 +737,4 @@ void KBBGame::slotResize()
     gameResize();
 }
 
-void KBBGame::slotKeyBindings()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
 #include "kbbgame.moc"
