@@ -13,7 +13,7 @@
 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef BASE_FIELD_H
@@ -80,6 +80,4 @@ class BaseField : public KGrid2D::Square<KMines::Case>, public KMines
     void changeState(KMines::CaseState, int increment);
 };
 
-QTextStream &operator <<(QTextStream &, const BaseField &);
-
 #endif
