@@ -1,6 +1,6 @@
 /*
  * card.c - functions to convert cards and card components to and from
- * its user representation. 
+ * its user representation.
  *
  * Written by Shlomi Fish (shlomif@vipe.technion.ac.il), 2000
  *
@@ -11,6 +11,10 @@
 
 #include "card.h"
 
+#ifdef DMALLOC
+#include "dmalloc.h"
+#endif
+
 
 #define uc(c) ( (((c)>='a') && ((c)<='z')) ?  ((c)+'A'-'a') : (c))
 
@@ -19,7 +23,7 @@
  * (e.g: "A", "K", "9") to its card number that can be used by
  * the program.
  * */
-int fcs_u2p_card_number(const char * string)
+int freecell_solver_u2p_card_number(const char * string)
 {
     char rest;
 
@@ -74,7 +78,7 @@ int fcs_u2p_card_number(const char * string)
  * The suit letter may come somewhat after the beginning of the string.
  *
  * */
-int fcs_u2p_suit(const char * suit)
+int freecell_solver_u2p_suit(const char * suit)
 {
     char c;
 
@@ -93,33 +97,33 @@ int fcs_u2p_suit(const char * suit)
 
     if (c == 'H')
         return 0;
-    else if (c == 'S')
+    else if (c == 'C')
         return 1;
     else if (c == 'D')
         return 2;
-    else if (c == 'C')
+    else if (c == 'S')
         return 3;
     else
         return 0;
 }
 
-int fcs_u2p_flipped_status(const char * str)
+static int fcs_u2p_flipped_status(const char * str)
 {
     while (*str != '\0')
     {
         if ((*str != ' ') && (*str != '\t'))
         {
-            return (*str == '<');           
+            return (*str == '<');
         }
         str++;
     }
-    return 0;    
+    return 0;
 }
 /*
  * This function converts an entire card from its string representations
  * (e.g: "AH", "KS", "8D"), to a fcs_card_t data type.
  * */
-fcs_card_t fcs_card_user2perl(const char * str)
+fcs_card_t freecell_solver_card_user2perl(const char * str)
 {
     fcs_card_t card;
 #if defined(COMPACT_STATES)||defined(INDIRECT_STACK_STATES)
@@ -139,34 +143,34 @@ fcs_card_t fcs_card_user2perl(const char * str)
  *
  * Notice that there are two of them: one prints 10 and one prints T for the
  * 10 card.
- * 
+ *
  * */
 #ifdef CARD_DEBUG_PRES
-char card_map_3_10[14][4] = { "*", "A", "2", "3", "4", "5", "6", "7", "8", "9", "10", "J", "Q", "K" };
+static char card_map_3_10[14][4] = { "*", "A", "2", "3", "4", "5", "6", "7", "8", "9", "10", "J", "Q", "K" };
 
-char card_map_3_T[14][4] = { "*", "A", "2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K" };
+static char card_map_3_T[14][4] = { "*", "A", "2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K" };
 
 #else
-char card_map_3_10[14][4] = { " ", "A", "2", "3", "4", "5", "6", "7", "8", "9", "10", "J", "Q", "K" };
+static char card_map_3_10[14][4] = { " ", "A", "2", "3", "4", "5", "6", "7", "8", "9", "10", "J", "Q", "K" };
 
-char card_map_3_T[14][4] = { " ", "A", "2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K" };
+static char card_map_3_T[14][4] = { " ", "A", "2", "3", "4", "5", "6", "7", "8", "9", "T", "J", "Q", "K" };
 
 #endif
 
 /*
  * Converts a card_number from its internal representation to a string.
- * 
+ *
  * num - the card number
  * str - the string to output to.
- * card_num_is_null - a pointer to a bool that indicates whether 
+ * card_num_is_null - a pointer to a bool that indicates whether
  *      the card number is out of range or equal to zero
  * t - whether 10 should be printed as T or not.
  * flipped - whether the card is face down
  * */
-char * fcs_p2u_card_number(
-    int num, 
-    char * str, 
-    int * card_num_is_null, 
+char * freecell_solver_p2u_card_number(
+    int num,
+    char * str,
+    int * card_num_is_null,
     int t,
     int flipped)
 {
@@ -195,25 +199,25 @@ char * fcs_p2u_card_number(
         }
         else
         {
-            strncpy(str, card_map_3[0], strlen(card_map_3[0])+1); 
+            strncpy(str, card_map_3[0], strlen(card_map_3[0])+1);
             *card_num_is_null = 1;
-        }            
+        }
     }
     return str;
 }
 
 /*
- * Converts a suit to its user representation. 
+ * Converts a suit to its user representation.
  *
  * */
-char * fcs_p2u_suit(int suit, char * str, int card_num_is_null, int flipped)
+char * freecell_solver_p2u_suit(int suit, char * str, int card_num_is_null, int flipped)
 {
 #ifndef CARD_DEBUG_PRES
     if (flipped)
     {
         strncpy(str, "*", 2);
     }
-    else 
+    else
 #endif
     if (suit == 0)
     {
@@ -227,11 +231,11 @@ char * fcs_p2u_suit(int suit, char * str, int card_num_is_null, int flipped)
             strncpy(str, "H", 2);
     }
     else if (suit == 1)
-        strncpy(str, "S", 2);
+        strncpy(str, "C", 2);
     else if (suit == 2)
         strncpy(str, "D", 2);
     else if (suit == 3)
-        strncpy(str, "C", 2);
+        strncpy(str, "S", 2);
     else
         strncpy(str, " ", 2);
     return str;
@@ -239,9 +243,9 @@ char * fcs_p2u_suit(int suit, char * str, int card_num_is_null, int flipped)
 
 /*
  * Convert an entire card to its user representation.
- * 
+ *
  * */
-char * fcs_card_perl2user(fcs_card_t card, char * str, int t)
+char * freecell_solver_card_perl2user(fcs_card_t card, char * str, int t)
 {
     int card_num_is_null;
 #ifdef CARD_DEBUG_PRES
@@ -253,9 +257,9 @@ char * fcs_card_perl2user(fcs_card_t card, char * str, int t)
 #endif
 
     fcs_p2u_card_number(
-        fcs_card_card_num(card), 
-        str, 
-        &card_num_is_null, 
+        fcs_card_card_num(card),
+        str,
+        &card_num_is_null,
         t,
         fcs_card_get_flipped(card)
         );
@@ -265,9 +269,9 @@ char * fcs_card_perl2user(fcs_card_t card, char * str, int t)
      *
      * */
     fcs_p2u_suit(
-        fcs_card_suit(card), 
-        str+strlen(str), 
-        card_num_is_null, 
+        fcs_card_suit(card),
+        str+strlen(str),
+        card_num_is_null,
         fcs_card_get_flipped(card)
         );
 
