@@ -15,7 +15,7 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
   *******************************************************************************/  
 
@@ -47,9 +47,9 @@ void player::setCoordinates(int x, int y)
   yCoordinate=y;
 }
 
-void player::setComputer(bool computer)
+void player::setComputer(bool isComputer)
 {
-  this->computer=computer;
+  computer=isComputer;
   if(computer)
     keyPressed=true;
   else keyPressed=false;
