@@ -17,9 +17,6 @@
 #include <kprinter.h>
 #include <qclipboard.h>
 
-#include <stdlib.h>
-#include <unistd.h>
-
 #include "toplevel.moc"
 #include "playground.h"
 #include "soundfactory.h"
@@ -275,7 +272,7 @@ void TopLevel::setupKAction()
   KToggleAction* t = new KToggleAction(i18n("&No Sound"), 0, this, SLOT(soundOff()), actionCollection(), "speech_no_sound");
   if (!soundEnabled) t->setChecked(true);
 
-  createGUI("ktuberlingui.rc");
+  setupGUI();
 }
 
 // Reset gameboard
@@ -326,7 +323,7 @@ void TopLevel::open(const KURL &url)
 void TopLevel::fileSave()
 {
   KURL url = KFileDialog::getSaveURL
-                (getenv("HOME"),
+                ( QString::null,
 		 "*.tuberling");
 
   if (url.isEmpty())
@@ -359,12 +356,12 @@ void TopLevel::filePicture()
   QPixmap picture(playGround->getPicture());
 
   KURL url = KFileDialog::getSaveURL
-                (getenv("HOME"),
-                 i18n(  "*.xpm|UNIX pixmaps (*.xpm)\n"
-                        "*.jpg|JPEG compressed files (*.jpg)\n"
-                        "*.png|Next generation pictures (*.png)\n"
-                        "*.bmp|Windows bitmaps (*.bmp)\n"
-                        "*|All picture formats"));
+                ( QString::null,
+                 i18n(  "*.xpm|UNIX Pixmaps (*.xpm)\n"
+                        "*.jpg|JPEG Compressed Files (*.jpg)\n"
+                        "*.png|Next Generation Pictures (*.png)\n"
+                        "*.bmp|Windows Bitmaps (*.bmp)\n"
+                        "*|All Picture Formats"));
 
   if( url.isEmpty() )
     return;
