@@ -22,7 +22,7 @@ const char *BaseField::BUTTON_TEXTS[NB_BUTTON_TYPE] = {
 BaseField::BaseField(QWidget *w)
     : _widget(w), _boardLayout(0), _label(0), _button(0)
 {
-	top = new QGridLayout(w, 3, 5, 10);
+    top = new QGridLayout(w, 3, 5, 10);
 
     lcds = new QGridLayout(7, 1, 5);
     top->addLayout(lcds, 1, 0);
@@ -34,9 +34,6 @@ BaseField::BaseField(QWidget *w)
     top->addWidget(board, 1, 2);
 }
 
-BaseField::~BaseField()
-{}
-
 void BaseField::init(bool AI, bool multiplayer, bool server, bool first,
                      const QString &name)
 {
@@ -140,7 +137,7 @@ void BaseField::stop(bool gameover)
 
 void BaseField::gameOver(const KExtHighscore::Score &score, QWidget *parent)
 {
-    KNotifyClient::event("game over", i18n("Game Over"));
+    KNotifyClient::event(parent->winId(), "game over", i18n("Game Over"));
     KExtHighscore::submitScore(score, parent);
 }
 
